Test: * Won't highlight *

Test: Will highlight

Test: I'm italic and bold I am just bold.

Test: I'm bold and italic! I am just italic.

Test: A lot of underscores____________is okay

Test: This will all be bold __because of the placement of the center underscores.

Test: This will all be bold __ because of the placement of the center underscores.

Test: This will NOT all be bold because of the placement of the center underscores.__

Test: This will all be bold_ because the token is less than that of the surrounding.

Test: This is text bold italic bold with more text

Test: All will * be italic

Test: All will *be italic

Test: All will not be italic*

Test: All will not * be italic*

Test: All will * be bold

Test: All will *be italic*

Test: All will not* be bold**

Test: All will not * be bold**

Test: This is text bold italic bold with more text

Test: test test test test

Test: test test *test*

Test: test * test

Test: test ** test

Test: test test test test

Test: test_ test _test

Test: test _ test

Test: test __ test

Test: test (test) test

Test: test (test) test

One asterisk: *

One underscore: _

Two asterisks: **

With spaces: * *

Two underscores __

with spaces: _ _

three asterisks: *

with spaces: * * *

three underscores: ___

with spaces: _ _ _

One char: a